#
# spec file for package tnftp
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tnftp
Version:        20230507
Release:        1.4
Summary:        Enhanced FTP Client
License:        BSD-3-Clause
Group:          Productivity/Networking/Ftp/Clients
URL:            https://ftp.netbsd.org/pub/NetBSD/misc/tnftp/
Source0:        https://ftp.netbsd.org/pub/NetBSD/misc/tnftp/%{name}-%{version}.tar.gz
Source1:        https://ftp.netbsd.org/pub/NetBSD/misc/tnftp/%{name}-%{version}.tar.gz.asc
Source2:        tnftp.keyring
BuildRequires:  libopenssl-devel >= 1.1
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-alternatives
BuildRequires:  pkgconfig(libedit)
BuildRequires:  pkgconfig(ncurses)
Requires(post): update-alternatives
Requires(postun):update-alternatives
Conflicts:      ftp
Provides:       lukemftp = 1.6
Provides:       nkitb:%{_bindir}/ftp
Obsoletes:      lukemftp <= 1.5

%description
%{name} is the FTP (File Transfer Protocol) client from NetBSD.  FTP is a widely
used protocol for transferring files over the Internet and for archiving files.
%{name} provides some advanced features beyond the Linux netkit ftp client, but
maintains a similar user interface to the traditional ftp client.  It was
formerly called lukemftp.

%prep
%setup -q

%build
%configure \
  --enable-editcomplete \
  --without-local-libedit
#axe bundled library
rm -rf libedit
%make_build

%install
%make_install

mkdir -p %{buildroot}%{_sysconfdir}/alternatives
%if 0%{?suse_version} <= 1310
touch %{buildroot}%{_sysconfdir}/alternatives/ftp
touch %{buildroot}%{_sysconfdir}/alternatives/ftp.1.gz
%endif
ln -sf %{_sysconfdir}/alternatives/ftp %{buildroot}%{_bindir}/ftp
ln -sf %{_sysconfdir}/alternatives/ftp.1.gz %{buildroot}%{_mandir}/man1/ftp.1.gz

%post
update-alternatives --install %{_bindir}/ftp ftp %{_bindir}/%{name} 10 \
  --slave %{_mandir}/man1/ftp.1.gz ftp.1 %{_mandir}/man1/%{name}.1.gz

%postun
if [ "$1" = 0 ] ; then
  update-alternatives --remove ftp %{_bindir}/%{name}
fi

%files
%license COPYING
%doc ChangeLog NEWS README THANKS
%ghost %{_sysconfdir}/alternatives/ftp
%ghost %{_sysconfdir}/alternatives/ftp.1.gz
%{_bindir}/ftp
%{_mandir}/man1/ftp.1%{?ext_man}
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Sat May 13 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 20230507
  * Add timeout for SSL connection setup, defaulting to 60
    seconds.
  * Consistently use poll(2) instead of select(2).
  * Check EAGAIN as well as EINTR.
  * Simplify includes.
- Update to version 20230409
  * Add option sslnoverify to control validation of SSL
    certificates.
  * Add netrc processing to fetch-mode (URL on command line)
    to enable options and autologin via netrc.
  * Fix SSL cleanup in some error paths.
  * Support SSL certificate validation by default.
    FTPSSLNOVERIFY=1 in the environment to disable validation.
  * Handle relative URLs.
  * Improve ftp(1) markup.
  * Fix -? in a more portable manner.
* Fri May 20 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 20210827
  * Validate address in server's PASV and LPSV responses. Previously
    a hostile server could cause ftp to open a data connection elsewhere.
  * Avoid intermittent crashes by fixing signal handler restoration.
  * Fix intermittent failures in -q QUITTIME by not using restartable
    signals.
  * Set SO_KEEPALIVE on control connection to attempt to avoid timeouts.
  * Display usage to stdout with -?.
- Update to version 20200705:
  * Avoid crashes by exiting if lostpeer due to a signal
  * Issue PWD commands to the server only when we actually need the
    results, not speculatively, just in case we might.
  * Use "anonymous" instead of the local username for anonymous
    ftp. Avoids unnecesary information leak.
  * Use the first name we requested the http/https URL for, not any
    name we ended up with after random redirects.
  * Support using CONNECT for https:// via proxy.
  * Improve SSL error reporting, and IPv6 endpoint reporting.
  * Use the system glob() if required extensions are supported.
- Drop upstream fixed tnftp-20100108-am_and_libedit.patch
- Drop upstream fixed tnftp-verify_hostname.patch
* Tue May 26 2020 Cristian Rodríguez <crrodriguez@opensuse.org>
- tnftp ssl client should validate hostnames and certificates,
  so for example tnftp -d https://revoked.badssl.com/example
  fails to connect. (tnftp-verify_hostname.patch), There are
  at least two reports about this misbehaviour online but it has
  never been fixed. Patch targets openSSL 1.1.x and later
  so specify requirement in spec file.
* Mon Aug  8 2016 asterios.dramis@gmail.com
- Update to version 20151004:
  * Implement '-x xferbufsize' to set xferbuf size.
  * Add Server Name Indication (SNI) support for https.
  * Increase buffer limit used for response handling.
- Removed post/pre requirement coreutils (not needed).
- Fixes for update-alternatives usage.
* Tue Apr  7 2015 p.drouand@gmail.com
- Update to version 20141104
  * Portability fixes
- Changes from version 20141031
  * Ignore special character behaviour in filenames not provided
  by the user.
  * Fixes CVE-2014-8517.
  * Fix timeout on HTTP fetches.
- Remove tnftp-cve-2014-8517.patch; fixed on upstream release
* Thu Oct 30 2014 tchvatal@suse.com
- Apply fix for bnc#903011 CVE-2014-8517
  * tnftp-cve-2014-8517.patch
- Version bump to 20130505:
  * various triv fixes
  * more ssl support
  * refresh tnftp-20100108-am_and_libedit.patch
- Cleanup with spec-cleaner
- Use update-alternatives properly
- Do not verify the sig in spec, just let OBS do it
* Mon Apr 29 2013 mvyskocil@suse.com
- verify tarball using gpg-offline
- remove obsoleted PreReq and reformat spec
* Wed Apr 11 2012 andreas.stieger@gmx.de
- fix openSUSE builds
- add autoconf, automake, libtool build requirements
- remove INSTALL file from package
* Mon Aug  1 2011 crrodriguez@opensuse.org
- There is no need to check for ncurses, not directly used
  by this package but by libedit for which we use the system version.
* Sun Jul 31 2011 crrodriguez@opensuse.org
- First package version, this is the segue from lukemftp
